class pe_console::dashboard (
  $db_host,
  $db_password,
  $filebucket_host,
  $certname        = "pe-internal-dashboard.${::clientcert}",
  $db_port         = '3306',
  $db_database     = 'console',
  $db_username     = 'console',
  $inventory_host  = 'puppetinventory',
  $inventory_port  = '8140',
  $filebucket_port = '8140',
  $ca_host         = 'puppetca',
  $ca_port         = '8140',
  $dashboard_root  = '/opt/puppet/share/puppet-dashboard',
  $console_host    = '*',
  $console_port    = '443',
  $waitforcert     = '120',
  $no_longer_reporting_cutoff = '3600',
) {
  include pe_httpd
  include pe_console::common
  include pe_console::patch_spool_to_db

  File {
    ensure => file,
    owner  => 'puppet-dashboard',
    group  => 'puppet-dashboard',
    mode   => '0640',
    notify => Service['pe-httpd'],
  }

  file { '/var/log/pe-puppet-dashboard/delayed_job.log':
    ensure => file,
    notify => Service['pe-puppet-dashboard-workers'],
  }
  if $::osfamily == 'Debian' {
    # Debian needs extra enabling
    file_line { 'enable-puppet-dashboard-workers':
      ensure => present,
      path   => '/etc/default/pe-puppet-dashboard-workers',
      match  => 'START=',
      line   => 'START=yes',
      before => Service['pe-puppet-dashboard-workers'],
    }
  }

  service { 'pe-puppet-dashboard-workers':
    ensure    => running,
    enable    => true,
    subscribe => Service['pe-httpd'],
    require   => [
      File['/var/log/pe-console-auth/auth.log'],
      File['/etc/puppetlabs/console-auth/database.yml'],
      Exec['puppet-dashboard-plugin-dbmigrate'],
    ],
  }

  # Configuration files for the application
  file { '/etc/puppetlabs/puppet-dashboard/settings.yml':
    content => template('pe_console/settings.yml.erb'),
    require => Puppet_certificate[$certname],
  }
  file { '/etc/puppetlabs/puppet-dashboard/database.yml':
    content => template('pe_console/database.yml.erb'),
  }

  # Ensure plugins are installed and set up the dashboard
  exec { 'puppet-dashboard-plugin-pe_console_common':
    path      => '/opt/puppet/bin:/usr/bin:/bin',
    cwd       => $dashboard_root,
    command   => 'rake puppet:plugin:install PLUGIN=pe_console_common RACK_ENV=production',
    creates   => "${dashboard_root}/config/installed_plugins/pe_console_common",
    notify    => Service['pe-httpd'],
    require   => [
      File['/etc/puppetlabs/puppet-dashboard/settings.yml'],
      File['/etc/puppetlabs/puppet-dashboard/database.yml'],
    ],
  }
  exec { 'puppet-dashboard-plugin-dbmigrate':
    path        => '/opt/puppet/bin:/usr/bin:/bin',
    cwd         => $dashboard_root,
    command     => 'rake db:migrate RACK_ENV=production',
    refreshonly => true,
    subscribe   => Exec['puppet-dashboard-plugin-pe_console_common'],
    notify      => Service['pe-httpd'],
  }

  pe_httpd::vhost { 'puppetdashboard':
    content => template('pe_console/puppetdashboard.conf.erb'),
    require => [
      File["${dashboard_root}/certs/${certname}.ca_crl.pem"],
      File["${dashboard_root}/certs/${certname}.ca_cert.pem"],
      File["${dashboard_root}/certs/${certname}.cert.pem"],
      File["${dashboard_root}/certs/${certname}.private_key.pem"],
      File["${dashboard_root}/certs/${certname}.public_key.pem"],
    ],
  }

  # Certificate files used by the application
  puppet_certificate { $certname:
    ensure      => present,
    waitforcert => $waitforcert,
  }
  file { "${dashboard_root}/certs":
    ensure => directory,
    mode   => '0750',
  }
  file { "${dashboard_root}/certs/${certname}.ca_crl.pem":
    source  => '/etc/puppetlabs/puppet/ssl/crl.pem',
    require => Puppet_certificate[$certname],
  }
  file { "${dashboard_root}/certs/${certname}.ca_cert.pem":
    source  => '/etc/puppetlabs/puppet/ssl/certs/ca.pem',
    require => Puppet_certificate[$certname],
  }
  file { "${dashboard_root}/certs/${certname}.cert.pem":
    source  => "/etc/puppetlabs/puppet/ssl/certs/${certname}.pem",
    require => Puppet_certificate[$certname],
  }
  file { "${dashboard_root}/certs/${certname}.private_key.pem":
    source  => "/etc/puppetlabs/puppet/ssl/private_keys/${certname}.pem",
    require => Puppet_certificate[$certname],
  }
  file { "${dashboard_root}/certs/${certname}.public_key.pem":
    source  => "/etc/puppetlabs/puppet/ssl/public_keys/${certname}.pem",
    require => Puppet_certificate[$certname],
  }

}
